@@ -58,7 +58,7 @@ instance Arbitrary SigSubPacket where
         return (SigSubPacket crit pl)
 
 instance Arbitrary SigSubPacketPayload where
-    arbitrary = oneof [sct, set, ec, ts, re, ket, psa, rk, i, nd, phas, pcas, ksps, pks, puid, purl, kfs, suid, rfr, fs, st {-, es -}]
+    arbitrary = oneof [sct, set, ec, ts, re, ket, psa, rk, i, nd, phas, pcas, ksps, pks, puid, purl, kfs, suid, rfr, fs, st {-, es -}, udss, oss]
         where
             sct = arbitrary >>= return . SigCreationTime
             set = arbitrary >>= return . SigExpirationTime
@@ -82,12 +82,13 @@ instance Arbitrary SigSubPacketPayload where
             fs = arbitrary >>= return . Features
             st = arbitrary >>= \pka -> arbitrary >>= \ha -> arbitrary >>= \sh -> return (SignatureTarget pka ha sh)
             es = arbitrary >>= return . EmbeddedSignature -- FIXME: figure out why EmbeddedSignature fails to serialize properly
-            -- FIXME: finish this
+            udss = choose (100,110) >>= \a -> arbitrary >>= \b -> return (UserDefinedSigSub a b)
+            oss = choose (111,127) >>= \a -> arbitrary >>= \b -> return (OtherSigSub a b) -- FIXME: more comprehensive range
 
 --
 
 instance Arbitrary PubKeyAlgorithm where
-    arbitrary = elements [RSA, DSA, EC, ECDSA, DH]
+    arbitrary = elements [RSA, DSA, ECDH, ECDSA, DH]
 
 instance Arbitrary EightOctetKeyId where
     arbitrary = vector 8 >>= return . EightOctetKeyId . B.pack
