@@ -8,6 +8,7 @@ module Codec.Encryption.OpenPGP.Expirations (
  , getKeyExpirationTimesFromSignature
 ) where
 
+import Control.Lens ((&), (^.), _1)
 import Data.List (sort)
 import Data.Time.Clock (UTCTime)
 import Data.Time.Clock.POSIX (posixSecondsToUTCTime)
@@ -18,8 +19,8 @@ import Codec.Encryption.OpenPGP.Types
 isTKTimeValid :: UTCTime -> TK -> Bool
 isTKTimeValid ct key = ct >= keyCreationTime && ct < keyExpirationTime
     where
-        keyCreationTime = posixSecondsToUTCTime . realToFrac . _timestamp . _tkPKP $ key
-        keyExpirationTime = posixSecondsToUTCTime . realToFrac . ((+) (_timestamp . _tkPKP $ key)) . newest . concatMap getKeyExpirationTimesFromSignature $ (concatMap snd (_tkUIDs key) ++ concatMap snd (_tkUAts key))
+        keyCreationTime = key^.tkKey._1.timestamp & posixSecondsToUTCTime . realToFrac
+        keyExpirationTime = posixSecondsToUTCTime . realToFrac . ((+) (key^.tkKey._1.timestamp)) . newest . concatMap getKeyExpirationTimesFromSignature $ (concatMap snd (key^.tkUIDs) ++ concatMap snd (key^.tkUAts))
 	newest [] = maxBound
 	newest xs = last (sort xs)
 
