@@ -30,7 +30,7 @@ pkalgoAbbrev DSA = "D"
 pkalgoAbbrev ElgamalEncryptOnly = "g"
 pkalgoAbbrev DeprecatedRSAEncryptOnly = "-"
 pkalgoAbbrev DeprecatedRSASignOnly = "_"
-pkalgoAbbrev EC = "e"
+pkalgoAbbrev ECDH = "e"
 pkalgoAbbrev ECDSA = "E"
 pkalgoAbbrev ForbiddenElgamal = "f"
 pkalgoAbbrev DH = "d"
