@@ -9,7 +9,7 @@ module Codec.Encryption.OpenPGP.Serialize (
 ) where
 
 import Control.Applicative ((<$>),(<*>))
-import Control.Lens ((^.))
+import Control.Lens ((^.), _1)
 import Control.Monad (guard, liftM, mplus, replicateM, replicateM_)
 import qualified Crypto.PubKey.RSA as R
 import qualified Crypto.PubKey.DSA as D
@@ -158,6 +158,10 @@ instance Serialize SignaturePayload where
     get = getSignaturePayload
     put = putSignaturePayload
 
+instance Serialize TK where
+    get = undefined
+    put = putTK
+
 getSigSubPacket :: Get SigSubPacket
 getSigSubPacket = do
     l <- fmap fromIntegral getSubPacketLength
@@ -181,8 +185,8 @@ getSigSubPacket = do
                        return $ SigSubPacket crit (TrustSignature tl ta)
             | pt == 6 = do
                        apdre <- getByteString (l - 2)
-		       nul <- getWord8
-		       guard (nul == 0)
+                       nul <- getWord8
+                       guard (nul == 0)
                        return $ SigSubPacket crit (RegularExpression (B.copy apdre))
             | pt == 7 = do
                        r <- get
@@ -246,7 +250,7 @@ getSigSubPacket = do
                        hash <- getByteString (l - 3)
                        return $ SigSubPacket crit (SignatureTarget pka ha hash)
             | pt == 32 = do
-		       sp <- get :: Get SignaturePayload
+                       sp <- get :: Get SignaturePayload
                        return $ SigSubPacket crit (EmbeddedSignature sp)
             | pt > 99 && pt < 111 = do
                        payload <- getByteString (l - 1)
@@ -468,7 +472,10 @@ getS2K = getS2K' =<< getWord8
                           salt <- getByteString 8
                           count <- getWord8
                           return $ IteratedSalted (toFVal ha) salt (decodeIterationCount count)
-            | otherwise = error "Unknown S2K"
+            | otherwise = do
+                          len <- remaining
+                          bs <- getByteString len
+                          return $ OtherS2K t bs
 
 putS2K :: S2K -> Put
 putS2K (Simple hashalgo) = error ("confused by simple" ++ show hashalgo)
@@ -478,6 +485,7 @@ putS2K (IteratedSalted ha salt count) = do
     put ha
     putByteString salt
     putWord8 $ encodeIterationCount count
+putS2K (OtherS2K t bs) = putWord8 t >> putByteString bs
 
 getPacketTypeAndPayload :: Get (Word8, ByteString)
 getPacketTypeAndPayload = do
@@ -842,16 +850,22 @@ getSKAddendum pkp = do
                 return $ SUUnencrypted sk checksum
         255 -> do symenc <- getWord8
                   s2k <- getS2K
-                  iv <- getByteString (symEncBlockSize . toFVal $ symenc)
-                  remainder <- remaining
-                  encryptedblock <- getByteString remainder
-                  return $ SUS16bit (toFVal symenc) s2k iv encryptedblock
+                  case s2k of      -- FIXME: this is a mess
+                      OtherS2K _ _ -> return $ SUS16bit (toFVal symenc) s2k B.empty B.empty
+                      _ -> do
+                              iv <- getByteString (symEncBlockSize . toFVal $ symenc)
+                              remainder <- remaining
+                              encryptedblock <- getByteString remainder
+                              return $ SUS16bit (toFVal symenc) s2k iv encryptedblock
         254 -> do symenc <- getWord8
                   s2k <- getS2K
-                  iv <- getByteString (symEncBlockSize . toFVal $ symenc)
-                  remainder <- remaining
-                  encryptedblock <- getByteString remainder
-                  return $ SUSSHA1 (toFVal symenc) s2k iv encryptedblock
+                  case s2k of      -- FIXME: this is a mess
+                      OtherS2K _ _ -> return $ SUSSHA1 (toFVal symenc) s2k B.empty B.empty
+                      _ -> do
+                              iv <- getByteString (symEncBlockSize . toFVal $ symenc)
+                              remainder <- remaining
+                              encryptedblock <- getByteString remainder
+                              return $ SUSSHA1 (toFVal symenc) s2k iv encryptedblock
         symenc -> do iv <- getByteString (symEncBlockSize . toFVal $ symenc)
                      remainder <- remaining
                      encryptedblock <- getByteString remainder
@@ -1215,6 +1229,18 @@ putSignaturePayload (SigVOther pv bs) = do
     putWord8 pv
     putByteString bs
 
+putTK :: TK -> Put
+putTK key = do
+    put (PublicKey (key^.tkKey._1))
+    mapM_ (put . Signature) (_tkRevs key)
+    mapM_ putUid' (_tkUIDs key)
+    mapM_ putUat' (_tkUAts key)
+    mapM_ putSub' (_tkSubs key)
+    where
+        putUid' (u, sps) = put (UserId u) >> mapM_ (put . Signature) sps
+        putUat' (us, sps) = put (UserAttribute us) >> mapM_ (put . Signature) sps
+        putSub' (p, sps) = put p >> mapM_ (put . Signature) sps
+
 -- Stolen from Axman6
 many :: Get a -> Get [a]
 many p = many1 p `mplus` return []
