@@ -1,5 +1,5 @@
 -- SerializeForSigs.hs: OpenPGP (RFC4880) special serialization for signature purposes
--- Copyright © 2012-2013  Clint Adams
+-- Copyright © 2012-2014  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -34,7 +34,7 @@ putPKPforFingerprinting (PublicKeyPkt pkp@(PKPayload V4 _ _ _ _)) = do
     let bs = runPut $ put pkp
     putWord16be . fromIntegral $ B.length bs
     putByteString bs
-putPKPforFingerprinting _ = fail "This should never happen"
+putPKPforFingerprinting _ = fail "This should never happen (putPKPforFingerprinting)"
 
 putMPIforFingerprinting:: MPI -> Put
 putMPIforFingerprinting(MPI i) = let bs = integerToBEBS i in putByteString bs
@@ -48,7 +48,7 @@ putPartialSigforSigning (SignaturePkt (SigV4 st pka ha hashed _ _ _)) = do
     let hb = runPut $ mapM_ put hashed
     putWord16be . fromIntegral . B.length $ hb
     putByteString hb
-putPartialSigforSigning _ = fail "This should never happen"
+putPartialSigforSigning _ = fail "This should never happen (putPartialSigforSigning)"
 
 putSigTrailer :: Pkt -> Put
 putSigTrailer (SignaturePkt (SigV4 _ _ _ hs _ _ _)) = do
@@ -56,12 +56,12 @@ putSigTrailer (SignaturePkt (SigV4 _ _ _ hs _ _ _)) = do
             putWord8 0xff
             putWord32be . fromIntegral . (+6) . B.length $ runPut $ mapM_ put hs
             -- this +6 seems like a bug in RFC4880
-putSigTrailer _ = fail "This should never happen"
+putSigTrailer _ = fail "This should never happen (putSigTrailer)"
 
 putUforSigning :: Pkt -> Put
 putUforSigning u@(UserIdPkt _) = putUIDforSigning u
 putUforSigning u@(UserAttributePkt _) = putUAtforSigning u
-putUforSigning _ = fail "This should never happen"
+putUforSigning _ = fail "This should never happen (putUforSigning)"
 
 putUIDforSigning :: Pkt -> Put
 putUIDforSigning (UserIdPkt u) = do
@@ -69,7 +69,7 @@ putUIDforSigning (UserIdPkt u) = do
     let bs = encodeUtf8 . T.pack $ u
     putWord32be . fromIntegral . B.length $ bs
     putByteString bs
-putUIDforSigning _ = fail "This should never happen"
+putUIDforSigning _ = fail "This should never happen (putUIDforSigning)"
 
 putUAtforSigning :: Pkt -> Put
 putUAtforSigning (UserAttributePkt us) = do
@@ -77,7 +77,7 @@ putUAtforSigning (UserAttributePkt us) = do
     let bs = runPut (mapM_ put us)
     putWord32be . fromIntegral . B.length $ bs
     putByteString bs
-putUAtforSigning _ = fail "This should never happen"
+putUAtforSigning _ = fail "This should never happen (putUAtforSigning)"
 
 putSigforSigning :: Pkt -> Put
 putSigforSigning (SignaturePkt (SigV4 st pka ha hashed _ left16 mpis)) = do
@@ -92,7 +92,7 @@ putKeyforSigning (PublicKeyPkt pkp) = putKeyForSigning' pkp
 putKeyforSigning (PublicSubkeyPkt pkp) = putKeyForSigning' pkp
 putKeyforSigning (SecretKeyPkt pkp _) = putKeyForSigning' pkp
 putKeyforSigning (SecretSubkeyPkt pkp _) = putKeyForSigning' pkp
-putKeyforSigning _ = fail "This should never happen"
+putKeyforSigning x = fail ("This should never happen (putKeyforSigning) " ++ show (pktTag x) ++ "/" ++ show x)
 
 putKeyForSigning' :: PKPayload -> Put
 putKeyForSigning' pkp = do
