@@ -19,6 +19,7 @@ import Data.Char (toLower, toUpper)
 import Data.Data (Data)
 import Data.Hashable (Hashable(..))
 import Data.IxSet (IxSet)
+import Data.List (intercalate)
 import Data.List.Split (chunksOf)
 import Data.Monoid ((<>))
 import Data.Ord (comparing)
@@ -27,6 +28,7 @@ import qualified Data.Set as Set
 import Data.Typeable (Typeable)
 import Data.Word (Word8, Word16, Word32)
 import Numeric (readHex, showHex)
+import Text.PrettyPrint.ANSI.Leijen (Pretty(..), (<+>), hsep, space, text)
 
 type TimeStamp = Word32
 type Exportability = Bool
@@ -228,7 +230,7 @@ data PubKeyAlgorithm = RSA
                      | DeprecatedRSASignOnly
                      | ElgamalEncryptOnly
                      | DSA
-                     | EC
+                     | ECDH
                      | ECDSA
                      | ForbiddenElgamal
                      | DH
@@ -247,7 +249,7 @@ instance FutureVal PubKeyAlgorithm where
     fromFVal DeprecatedRSASignOnly = 3
     fromFVal ElgamalEncryptOnly = 16
     fromFVal DSA = 17
-    fromFVal EC = 18
+    fromFVal ECDH = 18
     fromFVal ECDSA = 19
     fromFVal ForbiddenElgamal = 20
     fromFVal DH = 21
@@ -257,7 +259,7 @@ instance FutureVal PubKeyAlgorithm where
     toFVal 3 = DeprecatedRSASignOnly
     toFVal 16 = ElgamalEncryptOnly
     toFVal 17 = DSA
-    toFVal 18 = EC
+    toFVal 18 = ECDH
     toFVal 19 = ECDSA
     toFVal 20 = ForbiddenElgamal
     toFVal 21 = DH
@@ -619,13 +621,21 @@ newtype TwentyOctetFingerprint = TwentyOctetFingerprint {unTOF :: ByteString}
     deriving (Data, Eq, Generic, Ord, Typeable)
 
 instance Show TwentyOctetFingerprint where
-    show = take 50 . concatMap (++" ") . concatMap (++[""]) . chunksOf 5 . chunksOf 4 . w8sToHex . B.unpack . unTOF
+    show = w8sToHex . B.unpack . unTOF
 
 instance Read TwentyOctetFingerprint where
     readsPrec _ = map ((TwentyOctetFingerprint . B.pack *** concat) . unzip) . chunksOf 20 . hexToW8s . filter (/= ' ')
 
 instance Hashable TwentyOctetFingerprint
 
+instance Pretty TwentyOctetFingerprint where
+    pretty = hsep . intercalate [space] . chunksOf 5 . map text . chunksOf 4 . take 40 . w8sToHex . B.unpack . unTOF
+
+newtype SpacedFingerprint = SpacedFingerprint { unSpacedFingerprint :: TwentyOctetFingerprint }
+
+instance Show SpacedFingerprint where
+    show = take 50 . concatMap (++" ") . concatMap (++[""]) . chunksOf 5 . chunksOf 4 . show . unSpacedFingerprint
+
 w8sToHex :: [Word8] -> String
 w8sToHex = map toUpper . concatMap ((\x -> if length x == 1 then '0':x else x) . flip showHex "")
 
@@ -676,6 +686,9 @@ data Pkt = PKESKPkt PacketVersion EightOctetKeyId PubKeyAlgorithm [MPI]
 
 instance Hashable Pkt
 
+instance Ord Pkt where
+    compare = comparing pktTag <> comparing hash -- FIXME: is there something saner?
+
 pktTag :: Pkt -> Word8
 pktTag (PKESKPkt {}) = 1
 pktTag (SignaturePkt _) = 2
