@@ -1,5 +1,5 @@
 -- Decrypt.hs: OpenPGP (RFC4880) recursive packet decryption
--- Copyright © 2013  Clint Adams
+-- Copyright © 2013-2014  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -11,6 +11,7 @@ module Data.Conduit.OpenPGP.Decrypt (
 
 import Control.Monad (when)
 import Control.Monad.IO.Class (MonadIO(..))
+import Control.Monad.Trans.Resource (MonadBaseControl, MonadResource, MonadThrow, runResourceT)
 import qualified Control.Monad.Trans.State.Lazy as S
 import qualified Crypto.Hash.SHA1 as SHA1
 import qualified Data.ByteString as B
@@ -63,7 +64,7 @@ conduitDecrypt' depth cb = CL.concatMapAccumM push def { _depth = depth }  -- FI
         ldpCheck l@(LiteralDataPkt {}) = S.get >>= \o -> S.put o { _lastLDP = Just . fromPkt $ l }
         ldpCheck _ = return ()
 
-decryptSEDP :: (MonadBaseControl IO m, MonadIO m, MonadThrow m, MonadUnsafeIO m) => Int -> InputCallback IO -> SKESK -> B.ByteString -> m [Pkt]
+decryptSEDP :: (MonadBaseControl IO m, MonadIO m, MonadThrow m) => Int -> InputCallback IO -> SKESK -> B.ByteString -> m [Pkt]
 decryptSEDP depth cb skesk bs = do -- FIXME: this shouldn't pass the whole SKESK
     passphrase <- liftIO $ cb "Input the passphrase I want"
     let key = skesk2Key skesk passphrase
@@ -72,7 +73,7 @@ decryptSEDP depth cb skesk bs = do -- FIXME: this shouldn't pass the whole SKESK
                         Right x -> x
     runResourceT $ CB.sourceLbs (BL.fromStrict decrypted) $= conduitGet get $= conduitDecompress $= conduitDecrypt' depth cb $$ CL.consume
 
-decryptSEIPDP :: (MonadBaseControl IO m, MonadIO m, MonadThrow m, MonadUnsafeIO m) => Int -> InputCallback IO -> SKESK -> B.ByteString -> m [Pkt]
+decryptSEIPDP :: (MonadBaseControl IO m, MonadIO m, MonadThrow m) => Int -> InputCallback IO -> SKESK -> B.ByteString -> m [Pkt]
 decryptSEIPDP depth cb skesk bs = do -- FIXME: this shouldn't pass the whole SKESK
     passphrase <- liftIO $ cb "Input the passphrase I want"
     let key = skesk2Key skesk passphrase
