@@ -81,8 +81,12 @@ testKeyIDandFingerprint fpr kf = do
     bs <- B.readFile $ "tests/data/" ++ fpr
     case runGet (get :: Get Pkt) bs of
         Left _ -> assertFailure $ "Decoding of " ++ fpr ++ " broke."
-        Right (PublicKeyPkt pkp) -> assertEqual ("for " ++ fpr) kf (either (const "unknown") show (eightOctetKeyID pkp) ++ "/" ++ show (fingerprint pkp))
+        Right (PublicKeyPkt pkp) -> do
+	                               assertEqual ("for " ++ fpr ++ " (spaceless)") (spaceless kf) (either (const "unknown") show (eightOctetKeyID pkp) ++ "/" ++ show (fingerprint pkp))
+	                               assertEqual ("for " ++ fpr ++ " (spaced)") kf (either (const "unknown") show (eightOctetKeyID pkp) ++ "/" ++ show (SpacedFingerprint (fingerprint pkp)))
         _ -> assertFailure "Expected public key, got something else."
+    where
+        spaceless = filter (/=' ')
 
 testKeyringLookup :: FilePath -> String -> Bool -> Assertion
 testKeyringLookup fpr eok expected = do
@@ -248,6 +252,7 @@ unitTests = testGroup "Unit Tests" [
    , testCase "simple.seckey" (testSerialization "simple.seckey")
    , testCase "v3-genericcert.sig" (testSerialization "v3-genericcert.sig")
    , testCase "sigs-with-regexes" (testSerialization "sigs-with-regexes")
+   , testCase "gnu-dummy-s2k-101-secret-key.gpg" (testSerialization "gnu-dummy-s2k-101-secret-key.gpg")
    ],
   testGroup "KeyID/fingerprint group" [
      testCase "v3 key" (testKeyIDandFingerprint "v3.key" "C7261095/CBD9 F412 6807 E405 CC2D  2712 1DF5 E86E  ")
